==================
Plone Intranet API
==================

The ``ploneintranet.api`` package provides a simple developer API to the most commonly used features of ploneintranet.

Microblogging API
-----------------

.. automodule:: ploneintranet.api.microblog.statusupdate
    :members:
    :undoc-members:
    :show-inheritance:

Previews API
------------

.. automodule:: ploneintranet.api.previews
    :members:
    :undoc-members:
    :show-inheritance:

User Profile API
----------------

.. automodule:: ploneintranet.api.userprofile
    :members:
    :undoc-members:
    :show-inheritance:

